@@ -1,5 +1,5 @@
 from os.path import realpath, join, split
-self_fns = {
+self_fns={
 'fr':'entry',
 'start_percent':'entry',
 'end_percent':'entry',
@@ -20,7 +20,7 @@ self_fns = {
 'Wshow_arr':'value'
 }
 
-octave_add_opts = {
+octave_add_opts={
 '0':0,
 '1':12,
 '2':24,
@@ -30,7 +30,7 @@ octave_add_opts = {
 '6':60
 }
 
-scale_keys = {
+scale_keys={
 'Chromatic (12/oct)':[0,1,2,3,4,5,6,7,8,9,10,11],
 'Major scale (7/oct)':[0,2,4,5,7,9,11],
 'Minor scale (7/oct)':[0,2,3,5,7,9,11],
@@ -57,30 +57,25 @@ key_opts={
 'B' :11
 }
 
-cmaps_opts = tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis','binary', 
-'bone', 'pink','spring', 'summer', 'autumn', 'winter', 'cool','hot','copper','Spectral', 
-'coolwarm', 'bwr', 'seismic','twilight', 'hsv', 'Paired', 'prism', 'ocean', 
+cmaps_opts=tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis', 
+'bone', 'pink','spring', 'summer', 'autumn', 'winter', 'cool','hot','copper', 
+'coolwarm', 'bwr', 'seismic','twilight', 'hsv', 'prism', 'ocean', 
 'terrain','brg', 'rainbow', 'jet'],key=lambda s: s.lower()))
 
-pth=split(realpath(__file__))[0]
-example_files_decomp = [join(pth,'anthem_datasets',d) for d in ['demo1.mat','demo2.mat','demo3.mat','demo4.mat']]
-example_files_raw = [join(pth,'anthem_datasets',d) for d in ['raw1.mat','raw2.mat']]
-example_cfg = [join(pth,'anthem_datasets',d) for d in ['demo1_cfg.p','demo2_cfg.p','demo3_cfg.p','demo4_cfg.p']]
-
 '''
-Google drive id's for .sf2 files from https://sites.google.com/site/soundfonts4u/
+Google drive id for .sf2 files from https://sites.google.com/site/soundfonts4u/
 '''
-sound_font = '1alSnxnB0JFE6mEGbUZwiYGxt2UsoO3pM'
-sound_presets = {
+sound_font='1alSnxnB0JFE6mEGbUZwiYGxt2UsoO3pM'
+sound_presets={
 'Piano':0,
 'Strings':24,
-'e-Piano':10,
+'E-Piano':10,
 'Pad':21
 }
 
 '''
 static variables
 '''
-
-C0 = 16.352
-fs = 44100
+C0=16.352
+fs=44100
+tooltipson=Fals
\ No newline at end of file
